![PyPI](https://img.shields.io/pypi/v/talonfmt)
![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/wenkokke/talonfmt)
![GitHub Workflow Status](https://github.com/wenkokke/talonfmt/actions/workflows/build.yml/badge.svg)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/wenkokke/talonfmt/dev.svg)](https://results.pre-commit.ci/latest/github/wenkokke/talonfmt/dev)

# talonfmt

Code formatter for Talon files.
